#! /usr/bin/env node

const program = require('commander')
const figlet = require('figlet');
const chalk = require('chalk');

program
  // 定义命令和参数
  .command('create [name]')
  .description('create a new project')
  // -f or --force 为强制创建，如果创建的目录存在则直接覆盖
  .option('-f, --force', '强制创建，如果创建的目录存在则直接覆盖')
  .action((name, options) => {
    // console.log(name)
    // name
    // 打印结果，输出用户手动输入的项目名字
    name && require('../lib/create.js')(name, options)    // 引入 create.js 文件
  })
// 配置 config 命令
// program
//   .command('config [value]')
//   .description('inspect and modify the config')
//   .option('-g, --get <path>', 'get value from option')
//   .option('-s, --set <path> <value>')
//   .option('-d, --delete <path>', 'delete option from config')
//   .action((value, options) => {
//     console.log('自定义config 命令：', value);
//   })
// 打印一个有趣的 help
program
  .on('--help', () => {
    // 使用 figlet 绘制 Logo
    console.log('\r\n' + figlet.textSync('handy-c', {
      font: 'Standard',
      horizontalLayout: 'default',
      verticalLayout: 'default',
      width: 80,
      whitespaceBreak: true
    }));
    // 新增说明信息
    console.log(`\r\n运行 ${chalk.cyan(`handy <command> --help`)} 查看详情\r\n`)
  })
program
  // 配置版本号信息
  .version(`v${require('../package.json').version}`)
  .usage('<command> [option]')

// 解析用户执行命令传入参数
program.parse(process.argv);